@@ -1,4 +1,4 @@
-"""Mongo database source helpers"""
+"""Mongo database source helpers and destination utilities"""
 
 import re
 from itertools import islice
@@ -23,6 +23,7 @@ from bson.timestamp import Timestamp
 from dlt.common import logger
 from dlt.common.configuration.specs import BaseConfiguration, configspec
 from dlt.common.data_writers import TDataItemFormat
+from dlt.common.schema import TTableSchema
 from dlt.common.time import ensure_pendulum_datetime
 from dlt.common.typing import TDataItem
 from dlt.common.utils import map_nested_in_place
@@ -870,124 +871,173 @@ class MongoDbCollectionResourceConfiguration(BaseConfiguration):
 def convert_mongo_shell_to_extended_json(query_string: str) -> str:
     """
     Convert MongoDB shell syntax to MongoDB Extended JSON v2 format.
-    
+
     This function handles common MongoDB shell constructs like ISODate, ObjectId,
     NumberLong, NumberDecimal, etc. and converts them to their Extended JSON equivalents
     that can be parsed by bson.json_util.
-    
+
     Args:
         query_string: A string containing MongoDB shell syntax
-        
+
     Returns:
         A string with MongoDB Extended JSON v2 format
-        
+
     Examples:
         >>> convert_mongo_shell_to_extended_json('ISODate("2010-01-01T00:00:00.000Z")')
         '{"$date": "2010-01-01T00:00:00.000Z"}'
-        
+
         >>> convert_mongo_shell_to_extended_json('ObjectId("507f1f77bcf86cd799439011")')
         '{"$oid": "507f1f77bcf86cd799439011"}'
     """
     converted = query_string
-    
+
     # Convert ISODate("...") to {"$date": "..."}
     # Pattern matches ISODate("2010-01-01T00:00:00.000+0000") or similar
-    converted = re.sub(
-        r'ISODate\("([^"]+)"\)',
-        r'{"$date": "\1"}',
-        converted
-    )
-    
+    converted = re.sub(r'ISODate\("([^"]+)"\)', r'{"$date": "\1"}', converted)
+
     # Convert ObjectId("...") to {"$oid": "..."}
-    converted = re.sub(
-        r'ObjectId\("([^"]+)"\)',
-        r'{"$oid": "\1"}',
-        converted
-    )
-    
+    converted = re.sub(r'ObjectId\("([^"]+)"\)', r'{"$oid": "\1"}', converted)
+
     # Convert NumberLong(...) to {"$numberLong": "..."}
     # Note: NumberLong can have quotes or not: NumberLong(123) or NumberLong("123")
-    converted = re.sub(
-        r'NumberLong\("([^"]+)"\)',
-        r'{"$numberLong": "\1"}',
-        converted
-    )
-    converted = re.sub(
-        r'NumberLong\(([^)]+)\)',
-        r'{"$numberLong": "\1"}',
-        converted
-    )
-    
+    converted = re.sub(r'NumberLong\("([^"]+)"\)', r'{"$numberLong": "\1"}', converted)
+    converted = re.sub(r"NumberLong\(([^)]+)\)", r'{"$numberLong": "\1"}', converted)
+
     # Convert NumberInt(...) to {"$numberInt": "..."}
-    converted = re.sub(
-        r'NumberInt\("([^"]+)"\)',
-        r'{"$numberInt": "\1"}',
-        converted
-    )
-    converted = re.sub(
-        r'NumberInt\(([^)]+)\)',
-        r'{"$numberInt": "\1"}',
-        converted
-    )
-    
+    converted = re.sub(r'NumberInt\("([^"]+)"\)', r'{"$numberInt": "\1"}', converted)
+    converted = re.sub(r"NumberInt\(([^)]+)\)", r'{"$numberInt": "\1"}', converted)
+
     # Convert NumberDecimal("...") to {"$numberDecimal": "..."}
     converted = re.sub(
-        r'NumberDecimal\("([^"]+)"\)',
-        r'{"$numberDecimal": "\1"}',
-        converted
+        r'NumberDecimal\("([^"]+)"\)', r'{"$numberDecimal": "\1"}', converted
     )
-    
+
     # Convert Timestamp(..., ...) to {"$timestamp": {"t": ..., "i": ...}}
     # Timestamp(1234567890, 1) -> {"$timestamp": {"t": 1234567890, "i": 1}}
     converted = re.sub(
-        r'Timestamp\((\d+),\s*(\d+)\)',
-        r'{"$timestamp": {"t": \1, "i": \2}}',
-        converted
+        r"Timestamp\((\d+),\s*(\d+)\)", r'{"$timestamp": {"t": \1, "i": \2}}', converted
     )
-    
+
     # Convert BinData(..., "...") to {"$binary": {"base64": "...", "subType": "..."}}
     converted = re.sub(
         r'BinData\((\d+),\s*"([^"]+)"\)',
         r'{"$binary": {"base64": "\2", "subType": "\1"}}',
-        converted
+        converted,
     )
-    
+
     # Convert MinKey() to {"$minKey": 1}
-    converted = re.sub(
-        r'MinKey\(\)',
-        r'{"$minKey": 1}',
-        converted
-    )
-    
+    converted = re.sub(r"MinKey\(\)", r'{"$minKey": 1}', converted)
+
     # Convert MaxKey() to {"$maxKey": 1}
-    converted = re.sub(
-        r'MaxKey\(\)',
-        r'{"$maxKey": 1}',
-        converted
-    )
-    
+    converted = re.sub(r"MaxKey\(\)", r'{"$maxKey": 1}', converted)
+
     # Convert UUID("...") to {"$uuid": "..."}
-    converted = re.sub(
-        r'UUID\("([^"]+)"\)',
-        r'{"$uuid": "\1"}',
-        converted
-    )
-    
+    converted = re.sub(r'UUID\("([^"]+)"\)', r'{"$uuid": "\1"}', converted)
+
     # Convert DBRef("collection", "id") to {"$ref": "collection", "$id": "id"}
     converted = re.sub(
-        r'DBRef\("([^"]+)",\s*"([^"]+)"\)',
-        r'{"$ref": "\1", "$id": "\2"}',
-        converted
+        r'DBRef\("([^"]+)",\s*"([^"]+)"\)', r'{"$ref": "\1", "$id": "\2"}', converted
     )
-    
+
     # Convert Code("...") to {"$code": "..."}
-    converted = re.sub(
-        r'Code\("([^"]+)"\)',
-        r'{"$code": "\1"}',
-        converted
-    )
-    
+    converted = re.sub(r'Code\("([^"]+)"\)', r'{"$code": "\1"}', converted)
+
     return converted
 
 
 __source_name__ = "mongodb"
+
+
+# MongoDB destination helper functions
+def process_file_items(file_path: str) -> list[dict]:
+    """Process items from a file path (JSONL format)."""
+    import json
+
+    documents = []
+    with open(file_path, "r") as f:
+        for line in f:
+            if line.strip():
+                doc = json.loads(line.strip())
+                documents.append(doc)  # Include all fields including DLT metadata
+    return documents
+
+
+def mongodb_insert(uri: str):
+    """Creates a dlt.destination for inserting data into a MongoDB collection.
+
+    Args:
+        uri (str): MongoDB connection URI including database.
+
+    Returns:
+        dlt.destination: A DLT destination object configured for MongoDB.
+    """
+    from urllib.parse import urlparse
+
+    parsed_uri = urlparse(uri)
+
+    # Handle both mongodb:// and mongodb+srv:// schemes
+    if uri.startswith("mongodb+srv://") or uri.startswith("mongodb://"):
+        # For modern connection strings (MongoDB Atlas), use the URI as-is
+        connection_string = uri
+        # Extract database from path or use default
+        database = (
+            parsed_uri.path.lstrip("/") if parsed_uri.path.lstrip("/") else "ingestr_db"
+        )
+    else:
+        # Legacy handling for backwards compatibility
+        host = parsed_uri.hostname or "localhost"
+        port = parsed_uri.port or 27017
+        username = parsed_uri.username
+        password = parsed_uri.password
+        database = (
+            parsed_uri.path.lstrip("/") if parsed_uri.path.lstrip("/") else "ingestr_db"
+        )
+
+        # Build connection string
+        if username and password:
+            connection_string = f"mongodb://{username}:{password}@{host}:{port}"
+        else:
+            connection_string = f"mongodb://{host}:{port}"
+
+        # Add query parameters if any
+        if parsed_uri.query:
+            connection_string += f"?{parsed_uri.query}"
+
+    state = {"first_batch": True}
+
+    def destination(items: TDataItem, table: TTableSchema) -> None:
+        import pyarrow
+        from pymongo import MongoClient
+
+        # Extract database name from connection string
+        # Get collection name from table metadata
+        collection_name = table["name"]
+
+        # Connect to MongoDB
+        with MongoClient(connection_string) as client:
+            db = client[database]
+            collection = db[collection_name]
+
+            # Process and insert documents
+            if isinstance(items, str):
+                documents = process_file_items(items)
+            elif isinstance(items, pyarrow.RecordBatch):
+                documents = [item for item in items.to_pylist()]
+            else:
+                documents = [item for item in items if isinstance(item, dict)]
+
+            if state["first_batch"] and documents:
+                collection.delete_many({})
+                state["first_batch"] = False
+
+            if documents:
+                collection.insert_many(documents)  # Insert all new data
+
+    return dlt.destination(
+        destination,
+        name="mongodb",
+        loader_file_format="typed-jsonl",
+        batch_size=1000,
+        naming_convention="snake_case",
+        loader_parallelism_strategy="sequential",
+    )
